"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ad_record_1 = require("../../records/ad.record");
const db_1 = require("../../utils/db");
const defaultObj = {
    name: "[test] Testowy",
    description: "Test",
    price: 0,
    url: "https://www.test.com/",
    lat: 0,
    lon: 0,
};
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
test("AdRecord.create inserts data to database", () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = new ad_record_1.AdRecord(defaultObj);
    yield ad.insert();
    expect(ad.id).toBeDefined();
}));
test("AdRecord.create returns uuid after create an record", () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = new ad_record_1.AdRecord(defaultObj);
    yield ad.insert();
    const foundRecord = yield ad_record_1.AdRecord.findOne(ad.id);
    expect(foundRecord).toBeDefined();
    expect(foundRecord.id).toBe(ad.id);
}));
test("AdRecord returns data from database for one entry.", () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.findOne("1");
    expect(ad).toBeDefined();
    expect(ad.id).toBe("1");
    expect(ad.description).not.toBe(null);
}));
test("AdRecord returns null from database for unexciting entry.", () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.findOne("test");
    expect(ad).toBeNull();
}));
test("AdRecord returns array of found entries.", () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll("");
    expect(ads).not.toEqual([]);
    expect(ads[0]).toBeDefined();
}));
test("AdRecord returns empty array when searching something that doesnt exist", () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll("ab---!");
    expect(ads).toEqual([]);
}));
test("AdRecord returns small amount of data", () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll("HEXEM");
    expect(ads[0].price).toBeUndefined();
}));
//# sourceMappingURL=ad.test.js.map